﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2015 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Drawing;
using HeuristicLab.Common;
using HeuristicLab.Core.Networks;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.Networks.Views.NetworkVisualization {
  [StorableClass]
  public sealed class PortVisualProperties : VisualProperties, IPortVisualProperties {
    [Storable]
    private Orientation orientation;
    public Orientation Orientation {
      get { return orientation; }
      set {
        if (orientation == value) return;
        orientation = value;
        OnChanged();
      }
    }

    [Storable]
    private double offset;
    public double Offset {
      get { return offset; }
      set {
        if (offset == value) return;
        offset = value;
        OnChanged();
      }
    }

    [Storable]
    private Color brushColor;
    public Color BrushColor {
      get { return brushColor; }
      set {
        if (brushColor == value) return;
        brushColor = value;
        OnChanged();
      }
    }

    [Storable]
    private Color penColor;
    public Color PenColor {
      get { return penColor; }
      set {
        if (penColor == value) return;
        penColor = value;
        OnChanged();
      }
    }

    #region Constructors & Cloning
    [StorableConstructor]
    private PortVisualProperties(bool deserializing) : base(deserializing) { }
    private PortVisualProperties(PortVisualProperties original, Cloner cloner)
      : base(original, cloner) {
      orientation = original.orientation;
      offset = original.offset;
      brushColor = original.brushColor;
      penColor = original.penColor;
    }

    public PortVisualProperties() {
      orientation = Orientation.South;
      offset = 0.5;
      brushColor = Color.RosyBrown;
      penColor = Color.Black;
    }

    public override IDeepCloneable Clone(Cloner cloner) {
      return new PortVisualProperties(this, cloner);
    }
    #endregion
  }
}
